from typing import Dict, List, Any

from checkov.common.models.enums import CheckCategories, CheckResult
from checkov.common.util.type_forcers import force_list
from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck


class AzureServiceFabricClusterProtectionLevel(BaseResourceCheck):
    def __init__(self):
        name = "Ensures that Service Fabric use three levels of protection available"
        id = "CKV_AZURE_125"
        supported_resources = ['azurerm_service_fabric_cluster']
        categories = [CheckCategories.ENCRYPTION]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf: Dict[str, List[Any]]) -> CheckResult:
        self.evaluated_keys = ['fabric_settings']
        settings_conf = force_list(conf.get('fabric_settings'))
        for setting in settings_conf:
            if setting and setting.get('name') == ['Security']:
                params = setting.get('parameters', [{}])[0]
                if params.get('name') == 'ClusterProtectionLevel' and params.get('value') == 'EncryptAndSign':
                    index = settings_conf.index(setting)
                    self.evaluated_keys = [f'fabric_settings/[{index}]/parameters/[0]/name',
                                           f'fabric_settings/[{index}]/parameters/[0]/value']
                    return CheckResult.PASSED
        return CheckResult.FAILED


check = AzureServiceFabricClusterProtectionLevel()



import json
import logging
from typing import List, Dict, Type, Optional, Tuple

from checkov.cloudformation.cfn_utils import get_folder_definitions
from checkov.cloudformation.context_parser import ContextParser
from checkov.cloudformation.graph_builder.graph_to_definitions import convert_graph_vertices_to_definitions
from checkov.cloudformation.graph_builder.local_graph import CloudformationLocalGraph
from checkov.common.parsers.node import DictNode
from checkov.common.graph.db_connectors.db_connector import DBConnector
from checkov.common.graph.graph_manager import GraphManager


class CloudformationGraphManager(GraphManager):
    def __init__(self, db_connector: DBConnector, source: str = "CloudFormation") -> None:
        super().__init__(db_connector=db_connector, parser=None, source=source)

    def build_graph_from_source_directory(
        self,
        source_dir: str,
        render_variables: bool = True,
        local_graph_class: Type[CloudformationLocalGraph] = CloudformationLocalGraph,
        parsing_errors: Optional[Dict[str, Exception]] = None,
        download_external_modules: bool = False,
        excluded_paths: Optional[List[str]] = None,
    ) -> Tuple[CloudformationLocalGraph, Dict[str, DictNode]]:
        logging.info(f"[CloudformationGraphManager] Parsing files in source dir {source_dir}")
        parsing_errors = {}
        definitions, definitions_raw = get_folder_definitions(source_dir, excluded_paths, parsing_errors)
        local_graph = self.build_graph_from_definitions(definitions, render_variables)
        rendered_definitions, _ = convert_graph_vertices_to_definitions(local_graph.vertices, source_dir)

        # TODO: replace with real graph rendering
        for cf_file in rendered_definitions.keys():
            file_definition = rendered_definitions.get(cf_file, None)
            file_definition_raw = definitions_raw.get(cf_file, None)
            if file_definition is not None and file_definition_raw is not None:
                cf_context_parser = ContextParser(cf_file, file_definition, file_definition_raw)
                logging.debug(
                    "Template Dump for {}: {}".format(cf_file, json.dumps(file_definition, indent=2, default=str))
                )
                cf_context_parser.evaluate_default_refs()
        return local_graph, rendered_definitions

    def build_graph_from_definitions(
        self, definitions: Dict[str, DictNode], render_variables: bool = True
    ) -> CloudformationLocalGraph:
        local_graph = CloudformationLocalGraph(definitions, source=self.source)
        local_graph.build_graph(render_variables=render_variables)

        return local_graph



from abc import abstractmethod
from typing import Dict, List, Callable, Optional, Any

from checkov.common.checks.base_check import BaseCheck
from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.common.multi_signature import multi_signature
from checkov.terraform.checks.data.registry import data_registry


class BaseDataCheck(BaseCheck):
    def __init__(self, name: str, id: str, categories: List[CheckCategories], supported_data: List[str],
                 guideline=None) -> None:
        super().__init__(name=name, id=id, categories=categories, supported_entities=supported_data,
                         block_type="data", guideline=guideline)
        self.supported_data = supported_data
        data_registry.register(self)

    def scan_entity_conf(self, conf: Dict[str, List[Any]], entity_type: str) -> CheckResult:
        if conf.get("count") == [0]:
            return CheckResult.UNKNOWN

        return self.scan_data_conf(conf, entity_type)

    @multi_signature()
    @abstractmethod
    def scan_data_conf(self, conf: Dict[str, List[Any]], entity_type: str) -> CheckResult:
        raise NotImplementedError()

    @classmethod
    @scan_data_conf.add_signature(args=["self", "conf"])
    def _scan_data_conf_self_conf(cls, wrapped: Callable[..., CheckResult]) -> Callable[..., CheckResult]:
        def wrapper(
            self: "BaseDataCheck", conf: Dict[str, List[Any]], entity_type: Optional[str] = None
        ) -> CheckResult:
            # keep default argument for entity_type so old code, that doesn't set it, will work.
            return wrapped(self, conf)

        return wrapper



from typing import Dict, Any

from checkov.common.models.enums import CheckResult
from checkov.kubernetes.checks.resource.base_container_check import BaseK8sContainerCheck


class AllowedCapabilitiesSysAdmin(BaseK8sContainerCheck):
    def __init__(self) -> None:
        name = "Do not use the CAP_SYS_ADMIN linux capability"
        # This provides the most privilege and is similar to root
        # https://kubernetes.io/docs/tasks/configure-pod-container/security-context/
        id = "CKV_K8S_39"
        # Location: container .securityContext.capabilities
        super().__init__(name=name, id=id)

    def scan_container_conf(self, metadata: Dict[str, Any], conf: Dict[str, Any]) -> CheckResult:
        self.evaluated_container_keys = ["securityContext/capabilities/add"]
        if conf.get("securityContext"):
            if conf["securityContext"].get("capabilities"):
                if conf["securityContext"]["capabilities"].get("add"):
                    if "SYS_ADMIN" in conf["securityContext"]["capabilities"]["add"]:
                        return CheckResult.FAILED
        return CheckResult.PASSED


check = AllowedCapabilitiesSysAdmin()



from __future__ import annotations

import json
import logging
import re
from typing import Any

from checkov.cloudformation.checks.resource.base_resource_check import BaseResourceCheck
from checkov.common.models.consts import SLS_DEFAULT_VAR_PATTERN
from checkov.common.models.enums import CheckResult, CheckCategories


class ECRPolicy(BaseResourceCheck):
    def __init__(self) -> None:
        name = "Ensure ECR policy is not set to public"
        id = "CKV_AWS_32"
        supported_resources = ("AWS::ECR::Repository",)
        categories = (CheckCategories.GENERAL_SECURITY,)
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf: dict[str, Any]) -> CheckResult:
        """
            Looks for public * policy for ecr repository:
            https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ecr-repository.html
        :param conf: aws_ecr_repository configuration
        :return: <CheckResult>
        """
        self.evaluated_keys = ["Properties/RepositoryPolicyText/Statement"]
        properties = conf.get("Properties")
        if not properties or not isinstance(properties, dict):
            return CheckResult.PASSED
        policy_text = properties.get("RepositoryPolicyText")
        if not policy_text:
            return CheckResult.PASSED
        if isinstance(policy_text, str):
            try:
                policy_text = json.loads(str(policy_text))
            except json.decoder.JSONDecodeError as e:
                if re.match(SLS_DEFAULT_VAR_PATTERN, str(policy_text)):
                    # Case where the template is a sub-CFN configuration inside a serverless configuration,
                    # and the policy is a variable expression
                    logging.info(f"Encountered variable expression {str(policy_text)} in resource ${self.entity_path}")
                else:
                    logging.error(
                        f"Malformed policy configuration {str(policy_text)} of resource {self.entity_path}\n{e}"
                    )
                return CheckResult.UNKNOWN
        if "Statement" in policy_text.keys() and isinstance(policy_text["Statement"], list):
            for statement_index, statement in enumerate(policy_text["Statement"]):
                if "Principal" in statement.keys():
                    for principal_index, principal in enumerate(statement["Principal"]):
                        if principal == "*" and not self.check_for_constrained_condition(statement):
                            self.evaluated_keys = [
                                f"Properties/RepositoryPolicyText/Statement/[{statement_index}]/Principal/[{principal_index}]"
                            ]
                            return CheckResult.FAILED
        return CheckResult.PASSED

    def check_for_constrained_condition(self, statement: dict[str, Any]) -> bool:
        """
        Checks to see if there is a constraint on a a wildcarded principal
        :param statement: statement from aws_repository_configuration
        :return: true if there is a constraint
        """
        if "Condition" in statement.keys():
            condition = statement["Condition"]
            if "ForAllValues:StringEquals" in condition.keys():
                if "aws:PrincipalOrgID" in condition["ForAllValues:StringEquals"].keys():
                    return True
        return False


check = ECRPolicy()



from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.arm.base_resource_check import BaseResourceCheck


class AKSNetworkPolicy(BaseResourceCheck):
    def __init__(self):
        # apiVersion 2017-08-03 = Fail - No networkProfile option to configure
        name = "Ensure AKS cluster has Network Policy configured"
        id = "CKV_AZURE_7"
        supported_resources = ['Microsoft.ContainerService/managedClusters']
        categories = [CheckCategories.KUBERNETES]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf):
        if "apiVersion" in conf:
            if conf["apiVersion"] == "2017-08-31":
                # No networkProfile option to configure
                return CheckResult.FAILED

        if "properties" in conf:
            if "networkProfile" in conf["properties"]:
                if "networkPolicy" in conf["properties"]["networkProfile"]:
                    if conf["properties"]["networkProfile"]["networkPolicy"]:
                        return CheckResult.PASSED
        return CheckResult.FAILED

check = AKSNetworkPolicy()



from typing import Any

from checkov.common.models.enums import CheckCategories, CheckResult
from checkov.terraform.checks.resource.base_resource_value_check import BaseResourceValueCheck


class RejectUnsignedCommits(BaseResourceValueCheck):
    def __init__(self) -> None:
        name = "Ensure commits are signed"
        id = "CKV_GLB_4"
        supported_resources = ["gitlab_project"]
        categories = [CheckCategories.GENERAL_SECURITY]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources,
                         missing_block_result=CheckResult.FAILED)

    def get_inspected_key(self) -> str:
        return "push_rules/[0]/reject_unsigned_commits"

    def get_expected_value(self) -> Any:
        return True


check = RejectUnsignedCommits()



from checkov.terraform.checks.resource.base_resource_value_check import BaseResourceValueCheck
from checkov.common.models.enums import CheckCategories
from checkov.common.models.consts import ANY_VALUE

class K8SNetworkPolicy(BaseResourceValueCheck):
    def __init__(self):
        name = "Ensure network policy is assigned to Kubernetes cluster."
        id = "CKV_YC_16"
        supported_resources = ["yandex_kubernetes_cluster"]
        categories = [CheckCategories.NETWORKING]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def get_inspected_key(self):
        return "network_policy_provider"

    def get_expected_value(self):
        return ANY_VALUE
    
check = K8SNetworkPolicy()


from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck
from checkov.common.models.enums import CheckResult, CheckCategories


class PolicyNoApplicationAny(BaseResourceCheck):
    def __init__(self):
        name = "Ensure security rules do not have 'applications' set to 'any' "
        id = "CKV_PAN_5"
        supported_resources = ['panos_security_policy','panos_security_rule_group']
        categories = [CheckCategories.NETWORKING]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf):
    
        # Check there is a rule defined in the resource
        if 'rule' in conf:

            # Report the area of evaluation
            self.evaluated_keys = ['rule']

            # Get all the rules defined in the resource
            rules = conf.get('rule')

            # Iterate over each rule
            for secrule in rules:

                # Check if applications is defined in the resource
                if 'applications' in secrule:

                    # If applications is defined, get the value
                    apps = secrule.get('applications')
                    
                    # The value "any" is overly permissive and is therefore a fail. The value "any" can only appear on its on, "any" with any other values in the list is rejected by Terraform during apply stage
                    if apps[0][0] == "any":
                        return CheckResult.FAILED
                    # Any non-any value is specifying an application, which is a pass
                else:
                    # If "applications" attribute is not defined, this is not valid and will fail during Terraform plan stage, and should therefore be a fail
                    return CheckResult.FAILED
            
            # No "any" found for the "applications" attribute for any rules, therefore we have a pass
            return CheckResult.PASSED

        # If there's no rules we have nothing to check
        return CheckResult.UNKNOWN


check = PolicyNoApplicationAny()



from checkov.common.models.consts import ANY_VALUE
from checkov.terraform.checks.resource.base_resource_value_check import BaseResourceValueCheck
from checkov.common.models.enums import CheckCategories


class ImagebuilderDistributionConfigurationEncryptedWithCMK(BaseResourceValueCheck):
    def __init__(self) -> None:
        name = "Ensure Image Builder Distribution Configuration encrypts AMI's " \
               "using KMS - a customer managed Key (CMK)"
        id = "CKV_AWS_199"
        supported_resources = ['aws_imagebuilder_distribution_configuration']
        categories = [CheckCategories.ENCRYPTION]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def get_inspected_key(self) -> str:
        return "distribution/[0]/ami_distribution_configuration/[0]/kms_key_id"

    def get_expected_value(self) -> str:
        return ANY_VALUE


check = ImagebuilderDistributionConfigurationEncryptedWithCMK()



from checkov.common.vcs.vcs_schema import VCSSchema


class BranchRestrictionsSchema(VCSSchema):
    def __init__(self):
        schema = \
            {
                "$schema": "http://json-schema.org/draft-04/schema#",
                "type": "object",
                "properties": {
                    "pagelen": {
                        "type": "integer"
                    },
                    "values": {
                        "type": "array",
                        "items": [
                            {
                                "type": "object",
                                "properties": {
                                    "kind": {
                                        "type": "string"
                                    },
                                    "users": {
                                        "type": "array",
                                        "items": {}
                                    },
                                    "links": {
                                        "type": "object",
                                        "properties": {
                                            "self": {
                                                "type": "object",
                                                "properties": {
                                                    "href": {
                                                        "type": "string"
                                                    }
                                                },
                                                "required": [
                                                    "href"
                                                ]
                                            }
                                        },
                                        "required": [
                                            "self"
                                        ]
                                    },
                                    "pattern": {
                                        "type": "string"
                                    },

                                    "branch_match_kind": {
                                        "type": "string"
                                    },
                                    "groups": {
                                        "type": "array",
                                        "items": {}
                                    },
                                    "type": {
                                        "type": "string"
                                    },
                                    "id": {
                                        "type": "integer"
                                    }
                                },
                                "required": [
                                    "kind",
                                    "users",
                                    "links",
                                    "pattern",
                                    "branch_match_kind",
                                    "groups",
                                    "type",
                                    "id"
                                ]
                            },
                            {
                                "type": "object",
                                "properties": {
                                    "kind": {
                                        "type": "string"
                                    },
                                    "users": {
                                        "type": "array",
                                        "items": {}
                                    },
                                    "links": {
                                        "type": "object",
                                        "properties": {
                                            "self": {
                                                "type": "object",
                                                "properties": {
                                                    "href": {
                                                        "type": "string"
                                                    }
                                                },
                                                "required": [
                                                    "href"
                                                ]
                                            }
                                        },
                                        "required": [
                                            "self"
                                        ]
                                    },
                                    "pattern": {
                                        "type": "string"
                                    },

                                    "branch_match_kind": {
                                        "type": "string"
                                    },
                                    "groups": {
                                        "type": "array",
                                        "items": {}
                                    },
                                    "type": {
                                        "type": "string"
                                    },
                                    "id": {
                                        "type": "integer"
                                    }
                                },
                                "required": [
                                    "kind",
                                    "users",
                                    "links",
                                    "pattern",
                                    "branch_match_kind",
                                    "groups",
                                    "type",
                                    "id"
                                ]
                            },
                            {
                                "type": "object",
                                "properties": {
                                    "kind": {
                                        "type": "string"
                                    },
                                    "users": {
                                        "type": "array",
                                        "items": {}
                                    },
                                    "links": {
                                        "type": "object",
                                        "properties": {
                                            "self": {
                                                "type": "object",
                                                "properties": {
                                                    "href": {
                                                        "type": "string"
                                                    }
                                                },
                                                "required": [
                                                    "href"
                                                ]
                                            }
                                        },
                                        "required": [
                                            "self"
                                        ]
                                    },
                                    "pattern": {
                                        "type": "string"
                                    },

                                    "branch_match_kind": {
                                        "type": "string"
                                    },
                                    "groups": {
                                        "type": "array",
                                        "items": {}
                                    },
                                    "type": {
                                        "type": "string"
                                    },
                                    "id": {
                                        "type": "integer"
                                    }
                                },
                                "required": [
                                    "kind",
                                    "users",
                                    "links",
                                    "pattern",
                                    "branch_match_kind",
                                    "groups",
                                    "type",
                                    "id"
                                ]
                            }
                        ]
                    },
                    "page": {
                        "type": "integer"
                    },
                    "size": {
                        "type": "integer"
                    }
                },
                "required": [
                    "pagelen",
                    "values",
                    "page",
                    "size"
                ]
            }
        super().__init__(schema=schema)


schema = BranchRestrictionsSchema()



from checkov.common.models.enums import CheckCategories, CheckResult
from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck


class SecurityGroupsIngressStatelessSecurityRules(BaseResourceCheck):
    def __init__(self):
        name = "Ensure security group has stateless ingress security rules"
        id = "CKV_OCI_21"
        supported_resources = ['oci_core_network_security_group_security_rule']
        categories = [CheckCategories.NETWORKING]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf):
        stateless = conf.get('stateless')
        direction = conf.get('direction')
        self.evaluated_keys = ["direction"]
        if direction[0] == 'INGRESS':
            self.evaluated_keys.append("stateless")
            if stateless is None or stateless[0] is False:
                return CheckResult.FAILED
            return CheckResult.PASSED
        return CheckResult.UNKNOWN

check = SecurityGroupsIngressStatelessSecurityRules()



# flake8: noqa
terms = [
    "\${{[ ]*github.event.issue.title[ ]*}}",
    "\${{[ ]*github.event.issue.body[ ]*}}",
    "\${{[ ]*github.event.pull_request.title[ ]*}}",
    "\${{[ ]*github.event.pull_request.body[ ]*}}",
    "\${{[ ]*github.event.comment.body[ ]*}}",
    "\${{[ ]*github.event.review.body[ ]*}}",
    "\${{[ ]*github.event.review_comment.body[ ]*}}",
    "\${{[ ]*github.event.pages.*.page_name[ ]*}}",
    "\${{[ ]*github.event.head_commit.message[ ]*}}",
    "\${{[ ]*github.event.head_commit.author.email[ ]*}}",
    "\${{[ ]*github.event.head_commit.author.name[ ]*}}",
    "\${{[ ]*github.event.commits.*.author.email[ ]*}}",
    "\${{[ ]*github.event.commits.*.author.name[ ]*}}",
    "\${{[ ]*github.event.pull_request.head.ref[ ]*}}",
    "\${{[ ]*github.event.pull_request.head.label[ ]*}}",
    "\${{[ ]*github.event.pull_request.head.repo.default_branch[ ]*}}",
    "\${{[ ]*github.head_ref[ ]*}}"
]



from __future__ import annotations

from pathlib import Path
from typing import Type, TYPE_CHECKING

from pycep.typing import BicepJson

from checkov.bicep.parser import Parser
from checkov.bicep.utils import get_scannable_file_paths
from checkov.common.graph.db_connectors.db_connector import DBConnector
from checkov.common.graph.graph_manager import GraphManager
from checkov.bicep.graph_builder.local_graph import BicepLocalGraph

if TYPE_CHECKING:
    from checkov.common.graph.graph_builder.local_graph import LocalGraph


class BicepGraphManager(GraphManager):
    def __init__(self, db_connector: DBConnector, source: str = "Bicep") -> None:
        super().__init__(db_connector=db_connector, parser=None, source=source)

    def build_graph_from_source_directory(
        self,
        source_dir: str,
        render_variables: bool = True,
        local_graph_class: Type[LocalGraph] = BicepLocalGraph,
        parsing_errors: dict[str, Exception] | None = None,
        download_external_modules: bool = False,
        excluded_paths: list[str] | None = None,
    ) -> tuple[LocalGraph, dict[Path, BicepJson]]:
        file_paths = get_scannable_file_paths(root_folder=source_dir)
        definitions, definitions_raw, parsing_errors = Parser().get_files_definitions(file_paths)  # type:ignore[assignment]
        local_graph = self.build_graph_from_definitions(definitions)

        return local_graph, definitions

    def build_graph_from_definitions(
        self, definitions: dict[Path, BicepJson], render_variables: bool = True
    ) -> BicepLocalGraph:
        local_graph = BicepLocalGraph(definitions)
        local_graph.build_graph(render_variables)
        return local_graph



from checkov.common.models.enums import CheckCategories, CheckResult
from checkov.kubernetes.checks.resource.base_spec_check import BaseK8Check


class PeerClientCertAuthTrue(BaseK8Check):

    def __init__(self):
        name = "Ensure that the --peer-client-cert-auth argument is set to true"
        id = "CKV_K8S_121"
        supported_kind = ['Pod']
        categories = [CheckCategories.KUBERNETES]
        super().__init__(name=name, id=id, categories=categories, supported_entities=supported_kind)

    def scan_spec_conf(self, conf, entity_type=None):
        if conf.get("metadata")['name'] == 'etcd':
            containers = conf.get('spec')['containers']
            for container in containers:
                if container.get("args") is not None:
                    if '--peer-client-cert-auth=true' not in container['args']:
                        return CheckResult.FAILED
            return CheckResult.PASSED
        return CheckResult.UNKNOWN


check = PeerClientCertAuthTrue()



from __future__ import annotations

from copy import deepcopy
from typing import TYPE_CHECKING, Any

from pycep.transformer import BicepElement

from checkov.bicep.graph_builder.graph_components.block_types import BlockType
from checkov.common.graph.graph_builder import Edge
from checkov.common.graph.graph_builder.variable_rendering.renderer import VariableRenderer

if TYPE_CHECKING:
    from checkov.bicep.graph_builder.local_graph import BicepLocalGraph


class BicepVariableRenderer(VariableRenderer):
    def __init__(self, local_graph: BicepLocalGraph) -> None:
        super().__init__(local_graph)

    def _render_variables_from_vertices(self) -> None:
        pass

    def evaluate_vertex_attribute_from_edge(self, edge_list: list[Edge]) -> None:
        edge = edge_list[0]
        origin_vertex_attributes = self.local_graph.vertices[edge.origin].attributes
        val_to_eval = deepcopy(origin_vertex_attributes.get(edge.label, ""))

        attr_path, attr_value = self.extract_dest_attribute_path_and_value(dest_index=edge.dest, origin_value=val_to_eval)

        if attr_path:
            self.local_graph.update_vertex_attribute(
                vertex_index=edge.origin,
                attribute_key=edge.label,
                attribute_value=attr_value,
                change_origin_id=edge.dest,
                attribute_at_dest=attr_path,
            )

    def extract_dest_attribute_path_and_value(self, dest_index: int, origin_value: Any) -> tuple[str, Any] | tuple[None, None]:
        if isinstance(origin_value, BicepElement):
            vertex = self.local_graph.vertices[dest_index]

            if vertex.block_type == BlockType.PARAM:
                default = vertex.attributes.get("default")
                if default:
                    return "default", default

        return None, None



from checkov.common.models.enums import CheckCategories
from checkov.terraform.checks.resource.base_resource_value_check import BaseResourceValueCheck


class MLComputeClusterMinNodes(BaseResourceValueCheck):
    def __init__(self):
        name = "Ensure Machine Learning Compute Cluster Minimum Nodes Set To 0"
        id = "CKV_AZURE_150"
        supported_resources = ['azurerm_machine_learning_compute_cluster']
        categories = [CheckCategories.GENERAL_SECURITY]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def get_inspected_key(self) -> str:
        return "scale_settings/[0]/min_node_count"

    def get_expected_value(self):
        return 0


check = MLComputeClusterMinNodes()



from typing import Dict

from checkov.common.parsers.node import StrNode, DictNode
from checkov.common.models.enums import CheckCategories, CheckResult
from checkov.cloudformation.checks.resource.base_resource_value_check import BaseResourceValueCheck


class QLDBLedgerDeletionProtection(BaseResourceValueCheck):
    def __init__(self) -> None:
        name = "Ensure QLDB ledger has deletion protection enabled"
        id = "CKV_AWS_172"
        supported_resources = ["AWS::QLDB::Ledger"]
        categories = [CheckCategories.GENERAL_SECURITY]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf: Dict[StrNode, DictNode]) -> CheckResult:
        # deletion protection is enabled on default
        if "DeletionProtection" not in conf.get("Properties", {}):
            return CheckResult.PASSED
        return super().scan_resource_conf(conf)

    def get_inspected_key(self) -> str:
        return "Properties/DeletionProtection"


check = QLDBLedgerDeletionProtection()



from typing import Iterable, Optional

from checkov.common.checks.base_check import BaseCheck
from checkov.common.graph.graph_builder.graph_components.block_types import BlockType
from checkov.common.models.enums import CheckCategories

from checkov.yaml_doc.registry import registry


class BaseYamlCheck(BaseCheck):
    def __init__(self, name: str, id: str, categories: "Iterable[CheckCategories]", supported_entities: "Iterable[str]",
                 block_type: BlockType, path: Optional[str] = None) -> None:
        super().__init__(
            name=name,
            id=id,
            categories=categories,
            supported_entities=supported_entities,
            block_type=block_type,
        )
        self.path = path
        registry.register(self)
